.. _install:

Installation
============
SKLL can be installed via ``pip`` for any Python version::

    pip install skll

or via ``conda`` (only for Python 3.6)::

    conda install -c defaults -c conda-forge -c desilinguist python=3.6 skll

It can also be downloaded directly from
`GitHub <http://github.com/EducationalTestingService/skll>`_.


License
=======
SKLL is distributed under the 3-clause BSD License.
